==> activity-center-api-0.8.0.3-lqs3-20171115.113815-1-sources.jar: cn/com/duiba/tuia/activity/center/api/constant/FieldNameSpace.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:FieldNameSpace.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.constant<br>
 * Date:2017年3月9日下午5:32:42<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.constant;

/**
 * ClassName: FieldNameSpace <br/>
 * Function: 属性名常量. <br/>
 * Reason: 代码需要添写属性名时,使用此常量类. <br/>
 * date: 2017年3月9日 下午5:32:42 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class FieldNameSpace {

    /* A B C D E F G H I J K L M N O P Q R S T U V W X Y Z */ // sort

    public static final String ACTIVITY_TYPE      = "activityType";
    public static final String ACTIVITY_TYPE_NAME = "activityTypeName";
    public static final String ACTIVITY_IDS       = "activityIds";
    public static final String ACTIVITY_ID        = "activityId";
    public static final String ACTIVITY_PLANNER   = "activityPlanner";
    public static final String ACTIVITY_AMOUNT    = "activityAmount";
    public static final String ACT_CENTER_AMOUNT  = "actCenterAmount";
    public static final String ALIPAY_TYPE        = "alipayType";
    public static final String AUTO_OFF_DATE      = "autoOffDate";
    public static final String AWARD_LIMIT        = "awardLimit";
    public static final String APP_ID             = "appId";
    public static final String APP_IDS            = "appIds";

    public static final String BIRTHDAY           = "birthday";
    public static final String BIZ_TYPE            = "bizType";
    public static final String BUOY_ID            = "buoyId";
    public static final String BUOY_IDS           = "buoyIds";

    public static final String CHANNEL            = "channel";
    public static final String CUR_DATE           = "curDate";
    public static final String CODE               = "code";

    public static final String DAILY_BUDGET       = "dailyBudget";
    public static final String DATA_JSON          = "dataJson";
    public static final String DATA_CONFIG        = "dataConfig";
    public static final String DESC               = "desc";

    public static final String END                = "end";
    public static final String END_DATE           = "endDate";
    public static final String ENTRANCE_TYPE      = "entranceType";

    public static final String GMT_CREATE         = "gmtCreate";
    public static final String GMT_MODIFIED       = "gmtModified";
    public static final String GUARANTEED_COUNT   = "guaranteedCount";
    public static final String GROUP              = "group";

    public static final String HTML               = "html";

    public static final String ID                 = "id";
    public static final String IDENTIFICATION     = "identification";
    public static final String IDS                = "ids";
    public static final String IS_OPEN            = "isOpen";
    public static final String IS_BUOY            = "isBuoy";
    public static final String IS_DELETED         = "isDeleted";
    public static final String IMAGE              = "image";

    public static final String LAND_ID            = "landId";

    public static final String MAX                = "max";
    public static final String MAIN_MEET_AMOUNT   = "mainMeetAmount";
    public static final String MAX_AMOUNT         = "maxAmount";
    public static final String MIN_AMOUNT         = "minAmount";

    public static final String NAME               = "name";
    public static final String NUM_BUOY           = "numBuoy";

    public static final String OFFSET             = "offset";

    public static final String PAGE_TYPE          = "pageType";
    public static final String PRIZE_TYPE         = "prizeType";
    public static final String PRIZE_ID           = "prizeId";

    public static final String SKIN_NAME          = "skinName";
    public static final String SUBTYPE            = "subType";
    public static final String SUFFIX             = "suffix";
    public static final String STYLE_CONFIG       = "styleConfig";
    public static final String SLOT_IDS           = "slotIds";
    public static final String SLOT_ID            = "slotId";
    public static final String START              = "start";
    public static final String START_DATE         = "startDate";
    public static final String STATUS             = "status";
    public static final String STOCK              = "stock";
    public static final String STOCK_CHANGE       = "stockChange";
    public static final String STYLE_CODE         = "styleCode";

    public static final String TAG                = "tag";
    public static final String TITLE              = "title";
    public static final String TOTAL_STOCK        = "totalStock";
    public static final String TYPE               = "type";
    public static final String TYPES              = "types";

    public static final String USER_PHONE         = "userPhone";
    public static final String URL_INFO           = "urlInfo";

    public static final String VISION_PLANNER     = "visionPlanner";

    public static final String JOIN_TIMES         = "joinTimes";
    public static final String APPEAR_TYPE        = "appearType";
    public static final String PRIORITY           = "priority";

    private FieldNameSpace() {
    }
}

==> activity-center-api-0.8.9.1-lqs3-20180413.012950-1-sources.jar: cn/com/duiba/tuia/activity/center/api/constant/FieldNameSpace.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:FieldNameSpace.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.constant<br>
 * Date:2017年3月9日下午5:32:42<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.constant;

/**
 * ClassName: FieldNameSpace <br/>
 * Function: 属性名常量. <br/>
 * Reason: 代码需要添写属性名时,使用此常量类. <br/>
 * date: 2017年3月9日 下午5:32:42 <br/>
 *
 * @author wubo
 */
public class FieldNameSpace {

    /* A B C D E F G H I J K L M N O P Q R S T U V W X Y Z */ // sort

    public static final String COMMA              = ",";

    public static final String ACTIVITY_TYPE      = "activityType";
    public static final String ACTIVITY_TYPE_NAME = "activityTypeName";
    public static final String ACTIVITY_IDS       = "activityIds";
    public static final String ACTIVITY_ID        = "activityId";
    public static final String ACTIVITY_PLANNER   = "activityPlanner";
    public static final String ACTIVITY_AMOUNT    = "activityAmount";
    public static final String ACT_CENTER_AMOUNT  = "actCenterAmount";
    public static final String ALIPAY_TYPE        = "alipayType";
    public static final String AUTO_OFF_DATE      = "autoOffDate";
    public static final String AWARD_LIMIT        = "awardLimit";
    public static final String APP_ID             = "appId";
    public static final String APP_IDS            = "appIds";
    public static final String APPEAR_TYPE        = "appearType";

    public static final String BIRTHDAY           = "birthday";
    public static final String BIZ_TYPE           = "bizType";
    public static final String BUOY_ID            = "buoyId";
    public static final String BUOY_IDS           = "buoyIds";

    public static final String CHANNEL            = "channel";
    public static final String CUR_DATE           = "curDate";
    public static final String CODE               = "code";
    public static final String CID                = "cid";

    public static final String DAILY_BUDGET       = "dailyBudget";
    public static final String DATA_JSON          = "dataJson";
    public static final String DATA_CONFIG        = "dataConfig";
    public static final String DESC               = "desc";
    public static final String DEVICE_ID          = "deviceId";
    public static final String DIRECT_PAGE_LIST = "directPageList";

    public static final String END                = "end";
    public static final String END_DATE           = "endDate";
    public static final String ENTRANCE_TYPE      = "entranceType";

    public static final String GMT_CREATE         = "gmtCreate";
    public static final String GMT_MODIFIED       = "gmtModified";
    public static final String GUARANTEED_COUNT   = "guaranteedCount";
    public static final String GROUP              = "group";

    public static final String HTML               = "html";

    public static final String ID                 = "id";
    public static final String IDENTIFICATION     = "identification";
    public static final String IDS                = "ids";
    public static final String IS_OPEN            = "isOpen";
    public static final String IS_BUOY            = "isBuoy";
    public static final String IS_DELETED         = "isDeleted";
    public static final String IMAGE              = "image";

    public static final String JSON               = "json";

    public static final String LAND_ID            = "landId";
    public static final String LAND_IDS           = "landIds";

    public static final String MAX                = "max";
    public static final String MAIN_MEET_LIST     = "mainMeetList";
    public static final String MAIN_MEET_AMOUNT   = "mainMeetAmount";
    public static final String MAX_AMOUNT         = "maxAmount";
    public static final String MIN_AMOUNT         = "minAmount";

    public static final String NAME               = "name";
    public static final String NUM_BUOY           = "numBuoy";
    public static final String NOW_STATUS         = "nowStatus";

    public static final String OFFSET             = "offset";
    public static final String ORDER_IDS          = "orderIds";

    public static final String PAGE_TYPE          = "pageType";
    public static final String PRIZE_TYPE         = "prizeType";
    public static final String PRIZE_ID           = "prizeId";
    public static final String PRIZE_SCORE_TYPE   = "prizeScoreType";
    public static final String PRIORITY           = "priority";
    public static final String PRIZE_RECOMMEND_LIST = "prizeRecommendList";

    public static final String SKIN_NAME          = "skinName";
    public static final String SUBTYPE            = "subType";
    public static final String SUFFIX             = "suffix";
    public static final String STYLE_CONFIG       = "styleConfig";
    public static final String SLOT_IDS           = "slotIds";
    public static final String SLOT_ID            = "slotId";
    public static final String START              = "start";
    public static final String START_DATE         = "startDate";
    public static final String STATUS             = "status";
    public static final String STOCK              = "stock";
    public static final String STOCK_CHANGE       = "stockChange";
    public static final String STYLE_CODE         = "styleCode";

    public static final String TAG                = "tag";
    public static final String TITLE              = "title";
    public static final String TIME               = "time";
    public static final String TOTAL_STOCK        = "totalStock";
    public static final String TYPE               = "type";
    public static final String TYPES              = "types";

    public static final String USER_PHONE         = "userPhone";
    public static final String URL_INFO           = "urlInfo";
    public static final String URL_LIST           = "urlList";

    public static final String ACTIVITY_LIST = "activityList";

    public static final String JOIN_TIMES         = "joinTimes";

    public static final String RANDOM_TYPE        = "randomType";

    public static final String VISION_PLANNER     = "visionPlanner";








    public static final String MEDIA_USER_ID = "muId";
    public static final String PHONE = "phone";
    public static final String BALANCE_TYPE = "balance_type";

    public static final String CONSUMER_ID = "consumerId";

    public static final String ACTIVITY_CATEGORY      = "activityCategory";

    public static final String OVERSEAS      = "overseas";
    private FieldNameSpace() {
    }
}
